/**
 * @param {ReadonlyArray<Pattern>} patterns
 *   Patterns.
 * @param {string} lang
 *   Language.
 * @returns
 *   Plugin.
 */
export function createPlugin(patterns: ReadonlyArray<Pattern>, lang: string): (options?: Readonly<Options> | null | undefined) => (tree: Root, file: VFile) => undefined;
export type Parents = import('nlcst').Parents;
export type Root = import('nlcst').Root;
export type RootContent = import('nlcst').RootContent;
export type SearchHandle = import('nlcst-search').Handler;
export type VFile = import('vfile').VFile;
export type Pattern = import('./patterns-en.js').Pattern;
/**
 * Match.
 */
export type Match = {
    /**
     *   Type of match.
     */
    type: string;
    /**
     *   Parent of `nodes`.
     */
    parent: Parents;
    /**
     *   Nodes that match.
     */
    nodes: Array<RootContent>;
    /**
     *   Position of first of `nodes` in `parent`.
     */
    start: number;
    /**
     *   Position of last of `nodes` in `parent`.
     */
    end: number;
};
/**
 * Configuration.
 */
export type Options = {
    /**
     * Phrases *not* to warn about (optional).
     */
    ignore?: ReadonlyArray<string> | null | undefined;
    /**
     * Whether to allow “he or she”, “garbagemen and garbagewomen”, and similar
     * (default: `false`).
     */
    binary?: boolean | null | undefined;
};
