/**
 * @typedef Pattern
 * @property {boolean} [apostrophe]
 * @property {Array<string>} categories
 * @property {string} [condition]
 * @property {Record<string, string>} [considerate]
 * @property {string} id
 * @property {Record<string, string>} inconsiderate
 * @property {string} [note]
 * @property {'or' | 'basic'} type
 */

/** @type {ReadonlyArray<Pattern>} */
export const patterns = [
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with learning disabilities": "a"
    },
    "id": "learning-disabled",
    "inconsiderate": {
      "learning disabled": "a"
    },
    "note": "Refer to the person, rather than the disability, first.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "turned off": "a",
      "has a disability": "a",
      "person with a disability": "a",
      "people with disabilities": "a"
    },
    "id": "invalid",
    "inconsiderate": {
      "disabled": "a",
      "invalid": "a"
    },
    "note": "Refer to the person, rather than the disability, first.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "has a disability": "a",
      "person with a disability": "a",
      "people with disabilities": "a"
    },
    "id": "birth-defect",
    "inconsiderate": {
      "birth defect": "a"
    },
    "note": "Assumes/implies that a person with a disability is deficient or inferior to others. When possible, specify the functional ability or its restriction. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "has a disability": "a",
      "person with a disability": "a",
      "people with disabilities": "a"
    },
    "id": "suffers-from-disabilities",
    "inconsiderate": {
      "suffers from disabilities": "a",
      "suffering from disabilities": "a",
      "suffering from a disability": "a",
      "afflicted with disabilities": "a",
      "afflicted with a disability": "a"
    },
    "note": "Assumes that a person with a disability has a reduced quality of life. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "people with intellectual disabilities": "a"
    },
    "id": "intellectually-disabled-people",
    "inconsiderate": {
      "intellectually disabled people": "a"
    },
    "note": "Refer to the person, rather than the disability, first. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with an intellectual disability": "a"
    },
    "id": "intellectually-disabled",
    "inconsiderate": {
      "intellectually disabled": "a",
      "has intellectual issues": "a",
      "suffers from intellectual disabilities": "a",
      "suffering from intellectual disabilities": "a",
      "suffering from an intellectual disability": "a",
      "afflicted with intellectual disabilities": "a",
      "afflicted with a intellectual disability": "a"
    },
    "note": "Assumes that a person with an intellectual disability has a reduced quality of life. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "rude": "a",
      "malicious": "a",
      "mean": "a",
      "disgusting": "a",
      "incredible": "a",
      "vile": "a",
      "person with symptoms of mental illness": "a",
      "person with mental illness": "a",
      "person with symptoms of a mental disorder": "a",
      "person with a mental disorder": "a"
    },
    "id": "nuts",
    "inconsiderate": {
      "batshit": "a",
      "psycho": "a",
      "crazy": "a",
      "delirious": "a",
      "insane": "a",
      "insanity": "a",
      "loony": "a",
      "lunacy": "a",
      "lunatic": "a",
      "mentally ill": "a",
      "psychopathology": "a",
      "mental defective": "a",
      "moron": "a",
      "moronic": "a",
      "nuts": "a",
      "mental case": "a",
      "mental": "a"
    },
    "note": "Describe the behavior or illness without derogatory words. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "incredibly": "a"
    },
    "id": "insanely",
    "inconsiderate": {
      "insanely": "a"
    },
    "note": "Describe the behavior or illness without derogatory words.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "correct": "a",
      "adequate": "a",
      "sufficient": "a",
      "consistent": "a",
      "valid": "a",
      "coherent": "a",
      "sensible": "a",
      "reasonable": "a"
    },
    "id": "sane",
    "inconsiderate": {
      "sane": "a"
    },
    "note": "When describing a mathematical or programmatic value, using the word “sane” needlessly invokes the topic of mental health.  Consider using a domain-specific or neutral term instead.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "check": "a",
      "assertion": "a",
      "validation": "a",
      "smoke test": "a"
    },
    "id": "sanity-check",
    "inconsiderate": {
      "sanity check": "a"
    },
    "note": "When describing a mathematical or programmatic value, using the phrase “sanity check” needlessly invokes the topic of mental health.  Consider using simply “check”, or a domain-specific or neutral term, instead.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "fluctuating": "a",
      "person with bipolar disorder": "a"
    },
    "id": "bipolar",
    "inconsiderate": {
      "bipolar": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with schizophrenia": "a"
    },
    "id": "schizo",
    "inconsiderate": {
      "schizophrenic": "a",
      "schizo": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with schizophrenia": "a"
    },
    "id": "manic",
    "inconsiderate": {
      "suffers from schizophrenia": "a",
      "suffering from schizophrenia": "a",
      "afflicted with schizophrenia": "a",
      "manic": "a"
    },
    "note": "Assumes a person with schizophrenia experiences a reduced quality of life. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "accessible parking": "a"
    },
    "id": "handicapped-parking",
    "inconsiderate": {
      "handicapped parking": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a handicap": "a",
      "accessible": "a"
    },
    "id": "handicapped",
    "inconsiderate": {
      "handicapped": "a"
    },
    "note": "Refer to the person, rather than the disability, first. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with an amputation": "a"
    },
    "id": "amputee",
    "inconsiderate": {
      "amputee": "a"
    },
    "note": "Refer to the person, rather than the condition, first. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a limp": "a"
    },
    "id": "gimp",
    "inconsiderate": {
      "cripple": "a",
      "crippled": "a",
      "gimp": "a"
    },
    "note": "Refer to the specific disability.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with Down Syndrome": "a"
    },
    "id": "mongoloid",
    "inconsiderate": {
      "mongoloid": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "individual who has had a stroke": "a"
    },
    "id": "stroke-victim",
    "inconsiderate": {
      "stroke victim": "a",
      "suffering from a stroke": "a",
      "victim of a stroke": "a"
    },
    "note": "Refer to the person, rather than the condition, first.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person who has multiple sclerosis": "a"
    },
    "id": "multiple-sclerosis-victim",
    "inconsiderate": {
      "suffers from multiple sclerosis": "a",
      "suffering from multiple sclerosis": "a",
      "victim of multiple sclerosis": "a",
      "multiple sclerosis victim": "a",
      "afflicted with multiple sclerosis": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person who has muscular dystrophy": "a"
    },
    "id": "suffers-from-md",
    "inconsiderate": {
      "suffers from muscular dystrophy": "a",
      "afflicted with muscular dystrophy": "a",
      "suffers from MD": "a",
      "afflicted with MD": "a"
    },
    "note": "Refer to a person's condition as a state, not as an affliction. (source: https://ncdj.org/style-guide)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "with family support needs": "a"
    },
    "id": "family-burden",
    "inconsiderate": {
      "family burden": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "psychiatric hospital": "a",
      "mental health hospital": "a"
    },
    "id": "asylum",
    "inconsiderate": {
      "asylum": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "chaos": "a",
      "hectic": "a",
      "pandemonium": "a"
    },
    "id": "bedlam",
    "inconsiderate": {
      "bedlam": "a",
      "madhouse": "a",
      "loony bin": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Down Syndrome": "a"
    },
    "id": "downs-syndrome",
    "inconsiderate": {
      "downs syndrome": "a"
    },
    "note": "Source: https://media.specialolympics.org/soi/files/press-kit/2014_FactSheet_Final.pdf",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "silly": "a",
      "dullard": "a",
      "person with Down Syndrome": "a",
      "person with developmental disabilities": "a",
      "delay": "a",
      "hold back": "a"
    },
    "id": "retard",
    "inconsiderate": {
      "retard": "a",
      "retarded": "a",
      "short bus": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sillies": "a",
      "dullards": "a",
      "people with developmental disabilities": "a",
      "people with Down’s Syndrome": "a",
      "delays": "a",
      "holds back": "a"
    },
    "id": "retards",
    "inconsiderate": {
      "retards": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a psychotic condition": "a",
      "person with psychosis": "a"
    },
    "id": "psychotic",
    "inconsiderate": {
      "psychotic": "a",
      "suffers from psychosis": "a",
      "suffering from psychosis": "a",
      "afflicted with psychosis": "a",
      "victim of psychosis": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "boring": "a",
      "dull": "a"
    },
    "id": "lame",
    "inconsiderate": {
      "lame": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with AIDS": "a"
    },
    "id": "aids-victim",
    "inconsiderate": {
      "suffering from aids": "a",
      "suffer from aids": "a",
      "suffers from aids": "a",
      "afflicted with aids": "a",
      "victim of aids": "a",
      "aids victim": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "uses a wheelchair": "a"
    },
    "id": "wheelchair-bound",
    "inconsiderate": {
      "confined to a wheelchair": "a",
      "bound to a wheelchair": "a",
      "restricted to a wheelchair": "a",
      "wheelchair bound": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "athletes": "a",
      "Special Olympics athletes": "a"
    },
    "id": "special-olympians",
    "inconsiderate": {
      "special olympians": "a",
      "special olympic athletes": "a"
    },
    "note": "When possible, use the exact discipline of sport. (source: https://media.specialolympics.org/soi/files/press-kit/2014_FactSheet_Final.pdf)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "non-disabled": "a"
    },
    "id": "ablebodied",
    "inconsiderate": {
      "ablebodied": "a"
    },
    "note": "Can imply that people with disabilities lack the ability to use their bodies well. Sometimes `typical` can be used. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a drug addiction": "a",
      "person recovering from a drug addiction": "a"
    },
    "id": "addict",
    "inconsiderate": {
      "addict": "a",
      "junkie": "a"
    },
    "note": "Addiction is a neurobiological disease. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "people with a drug addiction": "a",
      "people recovering from a drug addiction": "a"
    },
    "id": "addicts",
    "inconsiderate": {
      "addicts": "a",
      "junkies": "a"
    },
    "note": "Addiction is a neurobiological disease. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "someone with an alcohol problem": "a"
    },
    "id": "alcoholic",
    "inconsiderate": {
      "alcoholic": "a",
      "alcohol abuser": "a"
    },
    "note": "Alcoholism is a neurobiological disease. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "deaf": "a"
    },
    "id": "deafmute",
    "inconsiderate": {
      "deaf and dumb": "a",
      "deafmute": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with dementia": "a"
    },
    "id": "senile",
    "inconsiderate": {
      "demented": "a",
      "senile": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sad": "a",
      "blue": "a",
      "bummed out": "a",
      "person with seasonal affective disorder": "a",
      "person with psychotic depression": "a",
      "person with postpartum depression": "a"
    },
    "id": "depressed",
    "inconsiderate": {
      "depressed": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with dwarfism": "a",
      "little person": "a",
      "little people": "a",
      "LP": "a",
      "person of short stature": "a"
    },
    "id": "dwarf",
    "inconsiderate": {
      "vertically challenged": "a",
      "midget": "a",
      "small person": "a",
      "dwarf": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/,https://www.lpaonline.org/faq-#Midget",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with dyslexia": "a"
    },
    "id": "dyslexic",
    "inconsiderate": {
      "dyslexic": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with epilepsy": "a"
    },
    "id": "epileptic",
    "inconsiderate": {
      "epileptic": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "hard of hearing": "a",
      "partially deaf": "a",
      "partial hearing loss": "a",
      "deaf": "a"
    },
    "id": "hearing-impaired",
    "inconsiderate": {
      "hearing impaired": "a",
      "hearing impairment": "a"
    },
    "note": "When possible, ask the person what they prefer. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "polio": "a",
      "person who had polio": "a"
    },
    "id": "victim-of-polio",
    "inconsiderate": {
      "infantile paralysis": "a",
      "suffers from polio": "a",
      "suffering from polio": "a",
      "suffering from a polio": "a",
      "afflicted with polio": "a",
      "afflicted with a polio": "a",
      "victim of polio": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sustain an injury": "a",
      "receive an injury": "a"
    },
    "id": "victim-of-an-injury",
    "inconsiderate": {
      "suffer from an injury": "a",
      "suffers from an injury": "a",
      "suffering from an injury": "a",
      "afflicted with an injury": "a",
      "victim of an injury": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sustain injuries": "a",
      "receive injuries": "a"
    },
    "id": "victim-of-injuries",
    "inconsiderate": {
      "suffer from injuries": "a",
      "suffers from injuries": "a",
      "suffering from injuries": "a",
      "afflicted with injuries": "a",
      "victim of injuries": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with paraplegia": "a"
    },
    "id": "paraplegic",
    "inconsiderate": {
      "paraplegic": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with quadriplegia": "a"
    },
    "id": "quadriplegic",
    "inconsiderate": {
      "quadriplegic": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with cerebral palsy": "a",
      "twitch": "a",
      "flinch": "a",
      "hectic": "a"
    },
    "id": "spaz",
    "inconsiderate": {
      "spaz": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with cerebral palsy": "a",
      "twitch": "a",
      "flinch": "a"
    },
    "id": "spastic",
    "inconsiderate": {
      "spastic": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "stuttering": "a",
      "disfluency of speech": "a"
    },
    "id": "stammering",
    "inconsiderate": {
      "stammering": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person who stutters": "a"
    },
    "id": "stutterer",
    "inconsiderate": {
      "stutterer": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Tourette syndrome": "a"
    },
    "id": "tourettes-syndrome",
    "inconsiderate": {
      "tourettes syndrome": "a",
      "tourettes disorder": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "treatment center": "a"
    },
    "id": "rehab-center",
    "inconsiderate": {
      "rehab center": "a",
      "detox center": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "treatment": "a"
    },
    "id": "rehab",
    "inconsiderate": {
      "rehab": "a",
      "detox": "a"
    },
    "note": "Source: https://ncdj.org/style-guide/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a personality disorder": "a",
      "person with psychopathic personality": "a"
    },
    "id": "sociopath",
    "inconsiderate": {
      "sociopath": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "people with psychopathic personalities": "a",
      "people with a personality disorder": "a"
    },
    "id": "sociopaths",
    "inconsiderate": {
      "sociopaths": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition. (source: https://ncdj.org/style-guide/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "foolish": "a",
      "ludicrous": "a",
      "speechless": "a",
      "silent": "a"
    },
    "id": "dumb",
    "inconsiderate": {
      "dumb": "a"
    },
    "note": "Dumb here is used in 2 different contexts , the inability to talk or as a curse word. (source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "foolish": "a",
      "ludicrous": "a",
      "unintelligent": "a"
    },
    "id": "wacko",
    "inconsiderate": {
      "simpleton": "a",
      "stupid": "a",
      "wacko": "a",
      "whacko": "a",
      "low iq": "a"
    },
    "note": "Source: http://www.mmonjejr.com/2014/02/deconstructing-stupid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "fit of terror": "a",
      "scare": "a"
    },
    "id": "panic-attack",
    "inconsiderate": {
      "panic attack": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "thin": "a",
      "slim": "a"
    },
    "id": "bony",
    "inconsiderate": {
      "anorexic": "a",
      "bony": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "has an anxiety disorder": "a",
      "obsessive": "a",
      "pedantic": "a",
      "niggly": "a",
      "picky": "a"
    },
    "id": "ocd",
    "inconsiderate": {
      "neurotic": "a",
      "ocd": "a",
      "o.c.d": "a",
      "o.c.d.": "a"
    },
    "note": "Only use terms describing mental illness when referring to a professionally diagnosed medical condition. (source: https://english.stackexchange.com/questions/247550/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "restlessness": "a",
      "sleeplessness": "a"
    },
    "id": "insomnia",
    "inconsiderate": {
      "insomnia": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person who has insomnia": "a"
    },
    "id": "insomniac",
    "inconsiderate": {
      "insomniac": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "people who have insomnia": "a"
    },
    "id": "insomniacs",
    "inconsiderate": {
      "insomniacs": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "empty": "a",
      "sterile": "a",
      "infertile": "a"
    },
    "id": "barren",
    "inconsiderate": {
      "barren": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "careless": "a",
      "heartless": "a",
      "indifferent": "a",
      "insensitive": "a"
    },
    "id": "deaf-to",
    "inconsiderate": {
      "blind to": "a",
      "blind eye to": "a",
      "blinded by": "a",
      "deaf to": "a",
      "deaf ear to": "a",
      "deafened by": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "creep": "a",
      "fool": "a"
    },
    "id": "cretin",
    "inconsiderate": {
      "cretin": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "absurd": "a",
      "foolish": "a"
    },
    "id": "daft",
    "inconsiderate": {
      "daft": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "foolish": "a",
      "ludicrous": "a",
      "silly": "a"
    },
    "id": "idiot",
    "inconsiderate": {
      "feebleminded": "a",
      "feeble minded": "a",
      "idiot": "a",
      "imbecile": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with a cleft-lip and palate": "a"
    },
    "id": "harelipped",
    "inconsiderate": {
      "harelipped": "a",
      "cleftlipped": "a"
    },
    "note": "Sometimes it's cleft lip or palate, not both. Specify when possible. (source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "cleft-lip and palate": "a"
    },
    "id": "harelip",
    "inconsiderate": {
      "harelip": "a",
      "hare lip": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "fanatic": "a",
      "zealot": "a",
      "enthusiast": "a"
    },
    "id": "maniac",
    "inconsiderate": {
      "maniac": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person with prominent teeth": "a",
      "prominent teeth": "a"
    },
    "id": "buckteeth",
    "inconsiderate": {
      "bucktoothed": "a",
      "buckteeth": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "has a disability": "a",
      "person with a disability": "a",
      "people with disabilities": "a"
    },
    "id": "special",
    "inconsiderate": {
      "challenged": "a",
      "diffability": "a",
      "differently abled": "a",
      "handicapable": "a",
      "special": "a",
      "special needs": "a",
      "specially abled": "a"
    },
    "note": "Euphemisms for disabilities can be infantilizing. (source: http://cdrnys.org/blog/disability-dialogue/the-disability-dialogue-4-disability-euphemisms-that-need-to-bite-the-dust/,https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "disagreeable": "a",
      "uneducated": "a",
      "ignorant": "a",
      "naive": "a",
      "inconsiderate": "a"
    },
    "id": "libtard",
    "inconsiderate": {
      "fucktard": "a",
      "libtard": "a",
      "contard": "a"
    },
    "note": "Source: https://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "disorganized": "a",
      "distracted": "a",
      "energetic": "a",
      "hyperactive": "a",
      "impetuous": "a",
      "impulsive": "a",
      "inattentive": "a",
      "restless": "a",
      "unfocused": "a"
    },
    "id": "add",
    "inconsiderate": {
      "ADD": "a",
      "adhd": "a",
      "a.d.d.": "a",
      "a.d.h.d.": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "test double": "a",
      "placeholder": "a",
      "fake": "a",
      "stub": "a"
    },
    "id": "dummy",
    "inconsiderate": {
      "dummyvariable": "a",
      "dummyvalue": "a",
      "dummyobject": "a",
      "dummy": "a"
    },
    "note": "Dummy can refer to the inability to talk or be used as a derogatory word meaning stupid. In computer programming it is used where a value or behavior is unimportant. There are better alternatives for other use cases also.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "enthusiastic": "a",
      "spree": "a"
    },
    "id": "binge",
    "inconsiderate": {
      "binge": "a"
    },
    "note": "Binge might be insensitive towards folks with eating or drinking disorders (source: https://github.com/retextjs/retext-equality/issues/110)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "obvious",
    "inconsiderate": {
      "obvious": "a",
      "obviously": "a"
    },
    "note": "Not everything is as obvious as you might think. And if it isn’t obvious to the reader, it can hurt. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "just",
    "inconsiderate": {
      "just": "a"
    },
    "note": "Not everything is as easy as you might think. And if it isn’t easy for the reader, it can hurt. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "basically",
    "inconsiderate": {
      "basically": "a"
    },
    "note": "It’s probably not that basic. If you’re going to explain a confusing previous sentence with a clearer next sentence, why not drop the former and only use the latter? (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "simple",
    "inconsiderate": {
      "simple": "a",
      "simply": "a"
    },
    "note": "It’s probably not that simple. Even if it is, you probably don’t need to specifically say it. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "easy",
    "inconsiderate": {
      "easy": "a",
      "easily": "a"
    },
    "note": "It’s probably not that easy. Even if it is, you probably don’t need to specifically say it. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "of-course",
    "inconsiderate": {
      "of course": "a"
    },
    "note": "If it’s self-evident then maybe you don’t need to describe it. If it isn’t, don’t say it. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "clearly",
    "inconsiderate": {
      "clearly": "a"
    },
    "note": "If it’s self-evident then maybe you don’t need to describe it. If it isn’t, don’t say it. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "everyone-knows",
    "inconsiderate": {
      "everyone knows": "a"
    },
    "note": "If it’s self-evident then maybe you don’t need to describe it. If it isn’t, don’t say it. (source: https://css-tricks.com/words-avoid-educational-writing/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "id": "straightforward",
    "inconsiderate": {
      "straight forward": "a",
      "straightforward": "a",
      "straight forwardly": "a",
      "straightforwardly": "a"
    },
    "note": "It’s probably not that straight forward. Even if it is, you probably don’t need to specifically say it.",
    "type": "basic"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "condition": "when referring to a person",
    "considerate": {
      "their": "a",
      "theirs": "a",
      "them": "a"
    },
    "id": "her-him",
    "inconsiderate": {
      "her": "female",
      "hers": "female",
      "him": "male",
      "his": "male"
    },
    "type": "or"
  },
  {
    "apostrophe": true,
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "they": "a",
      "it": "a"
    },
    "id": "he-she",
    "inconsiderate": {
      "she": "female",
      "he": "male",
      "she'd": "female",
      "he'd": "male",
      "she'll": "female",
      "he'll": "male",
      "she's": "female",
      "he's": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "themselves": "a",
      "theirself": "a",
      "self": "a"
    },
    "id": "herself-himself",
    "inconsiderate": {
      "herself": "female",
      "himself": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "condition": "when referring to a person",
    "considerate": {
      "kid": "a",
      "child": "a",
      "youth": "a"
    },
    "id": "boy-girl",
    "inconsiderate": {
      "girl": "female",
      "boy": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "people": "a",
      "persons": "a",
      "folks": "a"
    },
    "id": "gals-man",
    "inconsiderate": {
      "women": "female",
      "girls": "female",
      "gals": "female",
      "ladies": "female",
      "man": "male",
      "boys": "male",
      "men": "male",
      "guys": "male",
      "dudes": "male",
      "gents": "male",
      "gentlemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "person": "a",
      "friend": "a",
      "pal": "a",
      "folk": "a",
      "individual": "a"
    },
    "id": "gal-guy",
    "inconsiderate": {
      "woman": "female",
      "gal": "female",
      "lady": "female",
      "babe": "female",
      "bimbo": "female",
      "chick": "female",
      "guy": "male",
      "lad": "male",
      "fellow": "male",
      "dude": "male",
      "bro": "male",
      "gentleman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "native land": "a",
      "homeland": "a"
    },
    "id": "fatherland-motherland",
    "inconsiderate": {
      "motherland": "female",
      "fatherland": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "native tongue": "a",
      "native language": "a"
    },
    "id": "father-tongue-mother-tongue",
    "inconsiderate": {
      "mother tongue": "female",
      "father tongue": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "first-year students": "a",
      "freshers": "a"
    },
    "id": "freshmen-freshwomen",
    "inconsiderate": {
      "freshwomen": "female",
      "freshmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "garbage collector": "a",
      "waste collector": "a",
      "trash collector": "a"
    },
    "id": "garbageman-garbagewoman",
    "inconsiderate": {
      "garbagewoman": "female",
      "garbageman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "garbage collectors": "a",
      "waste collectors": "a",
      "trash collectors": "a"
    },
    "id": "garbagemen-garbagewomen",
    "inconsiderate": {
      "garbagewomen": "female",
      "garbagemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "chair": "a",
      "head": "a",
      "chairperson": "a",
      "coordinator": "a",
      "committee head": "a",
      "moderator": "a",
      "presiding officer": "a"
    },
    "id": "chairman-chairwoman",
    "inconsiderate": {
      "chairwoman": "female",
      "chairman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "committee member": "a"
    },
    "id": "committee-man-committee-woman",
    "inconsiderate": {
      "committee woman": "female",
      "committee man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cowhand": "a"
    },
    "id": "cowboy-cowgirl",
    "inconsiderate": {
      "cowgirl": "female",
      "cowboy": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cowhands": "a"
    },
    "id": "cowboys-cowgirls",
    "inconsiderate": {
      "cowgirls": "female",
      "cowboys": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cattle rancher": "a"
    },
    "id": "cattleman-cattlewoman",
    "inconsiderate": {
      "cattlewoman": "female",
      "cattleman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cattle ranchers": "a"
    },
    "id": "cattlemen-cattlewomen",
    "inconsiderate": {
      "cattlewomen": "female",
      "cattlemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "chairs": "a",
      "chairpersons": "a",
      "coordinators": "a"
    },
    "id": "chairmen-chairwomen",
    "inconsiderate": {
      "chairwomen": "female",
      "chairmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "mail carrier": "a",
      "letter carrier": "a",
      "postal worker": "a"
    },
    "id": "postman-postwoman",
    "inconsiderate": {
      "postwoman": "female",
      "mailwoman": "female",
      "postman": "male",
      "mailman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "mail carriers": "a",
      "letter carriers": "a",
      "postal workers": "a"
    },
    "id": "postmen-postwomen",
    "inconsiderate": {
      "postwomen": "female",
      "mailwomen": "female",
      "postmen": "male",
      "mailmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "officer": "a",
      "police officer": "a"
    },
    "id": "chick-cop-policeman",
    "inconsiderate": {
      "policewoman": "female",
      "policeman": "male",
      "chick cop": "female"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "officers": "a",
      "police officers": "a"
    },
    "id": "policemen-policewomen",
    "inconsiderate": {
      "policewomen": "female",
      "policemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "flight attendant": "a"
    },
    "id": "steward-stewardess",
    "inconsiderate": {
      "stewardess": "female",
      "steward": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "flight attendants": "a"
    },
    "id": "stewardesses-stewards",
    "inconsiderate": {
      "stewardesses": "female",
      "stewards": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "member of congress": "a",
      "congress person": "a",
      "legislator": "a",
      "representative": "a"
    },
    "id": "congressman-congresswoman",
    "inconsiderate": {
      "congresswoman": "female",
      "congressman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "members of congress": "a",
      "congress persons": "a",
      "legislators": "a",
      "representatives": "a"
    },
    "id": "congressmen-congresswomen",
    "inconsiderate": {
      "congresswomen": "female",
      "congressmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fire fighter": "a",
      "fire officer": "a"
    },
    "id": "fireman-firewoman",
    "inconsiderate": {
      "firewoman": "female",
      "fireman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fire fighters": "a"
    },
    "id": "firemen-firewomen",
    "inconsiderate": {
      "firewomen": "female",
      "firemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fisher": "a",
      "crew member": "a",
      "fisherfolk": "a",
      "angler": "a"
    },
    "id": "fisherman-fisherwoman",
    "inconsiderate": {
      "fisherwoman": "female",
      "fisherman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fishers": "a"
    },
    "id": "fishermen-fisherwomen",
    "inconsiderate": {
      "fisherwomen": "female",
      "fishermen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "kinship": "a",
      "community": "a"
    },
    "id": "brotherhood-sisterhood",
    "inconsiderate": {
      "sisterhood": "female",
      "brotherhood": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "common person": "a",
      "average person": "a"
    },
    "id": "common-girl-common-man",
    "inconsiderate": {
      "common girl": "female",
      "common man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "business executive": "a",
      "entrepreneur": "a",
      "business person": "a",
      "professional": "a"
    },
    "id": "salaryman-salarywoman",
    "inconsiderate": {
      "businesswoman": "female",
      "salarywoman": "female",
      "businessman": "male",
      "salaryman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "business executives": "a",
      "entrepreneurs": "a"
    },
    "id": "salarymen-salarywomen",
    "inconsiderate": {
      "businesswomen": "female",
      "salarywomen": "female",
      "career girl": "female",
      "career woman": "female",
      "businessmen": "male",
      "salarymen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cleaner": "a"
    },
    "id": "janitor-janitress",
    "inconsiderate": {
      "cleaning lady": "female",
      "cleaning girl": "female",
      "cleaning woman": "female",
      "janitress": "female",
      "cleaning man": "male",
      "cleaning boy": "male",
      "janitor": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cleaners": "a",
      "housekeeping": "a"
    },
    "id": "janitors-janitresses",
    "inconsiderate": {
      "cleaning ladies": "female",
      "cleaning girls": "female",
      "janitresses": "female",
      "cleaning men": "male",
      "janitors": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "courier": "a",
      "messenger": "a"
    },
    "id": "delivery-boy-delivery-girl",
    "inconsiderate": {
      "delivery girl": "female",
      "delivery boy": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "supervisor": "a",
      "shift boss": "a"
    },
    "id": "foreman-forewoman",
    "inconsiderate": {
      "forewoman": "female",
      "foreman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "lead": "a",
      "front": "a",
      "figurehead": "a"
    },
    "id": "frontman,-front-man-frontwoman,-front-woman",
    "inconsiderate": {
      "frontwoman, front woman": "female",
      "frontman, front man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "figureheads": "a"
    },
    "id": "front-men,-frontmen-front-women,-frontwomen",
    "inconsiderate": {
      "front women, frontwomen": "female",
      "front men, frontmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "supervisors": "a",
      "shift bosses": "a"
    },
    "id": "foremen-forewomen",
    "inconsiderate": {
      "forewomen": "female",
      "foremen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "insurance agent": "a"
    },
    "id": "insurance-man-insurance-woman",
    "inconsiderate": {
      "insurance woman": "female",
      "insurance man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "insurance agents": "a"
    },
    "id": "insurance-men-insurance-women",
    "inconsiderate": {
      "insurance women": "female",
      "insurance men": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "proprietor": "a",
      "building manager": "a"
    },
    "id": "landlady-landlord",
    "inconsiderate": {
      "landlady": "female",
      "landlord": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "proprietors": "a",
      "building managers": "a"
    },
    "id": "landladies-landlords",
    "inconsiderate": {
      "landladies": "female",
      "landlords": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "graduate": "a"
    },
    "id": "alumna-alumnus",
    "inconsiderate": {
      "alumna": "female",
      "alumnus": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "graduates": "a"
    },
    "id": "alumnae-alumni",
    "inconsiderate": {
      "alumnae": "female",
      "alumni": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "anchor": "a",
      "journalist": "a"
    },
    "id": "newsman-newswoman",
    "inconsiderate": {
      "newswoman": "female",
      "newspaperwoman": "female",
      "anchorwoman": "female",
      "newsman": "male",
      "newspaperman": "male",
      "anchorman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "anchors": "a",
      "journalists": "a"
    },
    "id": "newsmen-newswomen",
    "inconsiderate": {
      "newswomen": "female",
      "newspaperwomen": "female",
      "anchorwomen": "female",
      "newsmen": "male",
      "newspapermen": "male",
      "anchormen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "repairer": "a",
      "technician": "a"
    },
    "id": "repairman-repairwoman",
    "inconsiderate": {
      "repairwoman": "female",
      "repairman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "technicians": "a"
    },
    "id": "repairmen-repairwomen",
    "inconsiderate": {
      "repairwomen": "female",
      "repairmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "salesperson": "a",
      "sales clerk": "a",
      "sales rep": "a",
      "sales agent": "a",
      "sales attendant": "a",
      "seller": "a",
      "shop assistant": "a"
    },
    "id": "saleslady-salesman",
    "inconsiderate": {
      "saleswoman": "female",
      "sales woman": "female",
      "saleslady": "female",
      "salesman": "male",
      "sales man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "sales clerks": "a",
      "sales reps": "a",
      "sales agents": "a",
      "sellers": "a"
    },
    "id": "salesmen-saleswomen",
    "inconsiderate": {
      "saleswomen": "female",
      "sales women": "female",
      "salesladies": "female",
      "salesmen": "male",
      "sales men": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "soldier": "a",
      "service representative": "a"
    },
    "id": "serviceman-servicewoman",
    "inconsiderate": {
      "servicewoman": "female",
      "serviceman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "soldiers": "a",
      "service representatives": "a"
    },
    "id": "servicemen-servicewomen",
    "inconsiderate": {
      "servicewomen": "female",
      "servicemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "server": "a"
    },
    "id": "waiter-waitress",
    "inconsiderate": {
      "waitress": "female",
      "waiter": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "servers": "a"
    },
    "id": "waiters-waitresses",
    "inconsiderate": {
      "waitresses": "female",
      "waiters": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "worker": "a",
      "wage earner": "a",
      "taxpayer": "a"
    },
    "id": "workman-workwoman",
    "inconsiderate": {
      "workwoman": "female",
      "working woman": "female",
      "workman": "male",
      "working man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "workers": "a"
    },
    "id": "workmen-workwomen",
    "inconsiderate": {
      "workwomen": "female",
      "workmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "performer": "a",
      "star": "a",
      "artist": "a",
      "entertainer": "a"
    },
    "id": "actor-actress",
    "inconsiderate": {
      "actress": "female",
      "actor": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "performers": "a",
      "stars": "a",
      "artists": "a",
      "entertainers": "a"
    },
    "id": "actors-actresses",
    "inconsiderate": {
      "actresses": "female",
      "actors": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "pilot": "a",
      "aviator": "a",
      "airstaff": "a"
    },
    "id": "aircrewwoman-airman",
    "inconsiderate": {
      "aircrewwoman": "female",
      "aircrew woman": "female",
      "aircrewman": "male",
      "airman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "pilots": "a",
      "aviators": "a",
      "airstaff": "a"
    },
    "id": "aircrewwomen-airmen",
    "inconsiderate": {
      "aircrewwomen": "female",
      "aircrew women": "female",
      "aircrewmen": "male",
      "airmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cabinet member": "a"
    },
    "id": "alderman-alderwoman",
    "inconsiderate": {
      "alderwoman": "female",
      "alderman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "cabinet": "a",
      "cabinet members": "a",
      "alderperson": "a"
    },
    "id": "aldermen-alderwomen",
    "inconsiderate": {
      "alderwomen": "female",
      "aldermen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "assembly person": "a",
      "assembly worker": "a"
    },
    "id": "assemblyman-assemblywoman",
    "inconsiderate": {
      "assemblywoman": "female",
      "assemblyman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "relative": "a"
    },
    "id": "aunt-uncle",
    "inconsiderate": {
      "kinswoman": "female",
      "aunt": "female",
      "kinsman": "male",
      "uncle": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "relatives": "a"
    },
    "id": "aunts-uncles",
    "inconsiderate": {
      "kinswomen": "female",
      "aunts": "female",
      "kinsmen": "male",
      "uncles": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "boogeymonster": "a"
    },
    "id": "boogeyman-boogeywoman",
    "inconsiderate": {
      "boogeywoman": "female",
      "boogeyman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "boogeymonster": "a"
    },
    "id": "boogieman-boogiewoman",
    "inconsiderate": {
      "boogiewoman": "female",
      "boogieman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bogeymonster": "a"
    },
    "id": "bogeyman-bogeywoman",
    "inconsiderate": {
      "bogeywoman": "female",
      "bogeyman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bogeymonster": "a"
    },
    "id": "bogieman-bogiewoman",
    "inconsiderate": {
      "bogiewoman": "female",
      "bogieman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "boogeymonsters": "a"
    },
    "id": "boogiemen-boogiewomen",
    "inconsiderate": {
      "boogiewomen": "female",
      "boogiemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bogeymonsters": "a"
    },
    "id": "bogiemen-bogiewomen",
    "inconsiderate": {
      "bogiewomen": "female",
      "bogiemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bonder": "a"
    },
    "id": "bondsman-bondswoman",
    "inconsiderate": {
      "bondswoman": "female",
      "bondsman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bonders": "a"
    },
    "id": "bondsmen-bondswomen",
    "inconsiderate": {
      "bondswomen": "female",
      "bondsmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "partner": "a",
      "significant other": "a",
      "spouse": "a"
    },
    "id": "husband-wife",
    "inconsiderate": {
      "wife": "female",
      "husband": "male"
    },
    "note": "Source: https://www.bustle.com/articles/108321-6-reasons-to-refer-to-your-significant-other-as-your-partner",
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "partners": "a",
      "significant others": "a",
      "spouses": "a"
    },
    "id": "husbands-wives",
    "inconsiderate": {
      "wives": "female",
      "husbands": "male"
    },
    "note": "Source: https://www.bustle.com/articles/108321-6-reasons-to-refer-to-your-significant-other-as-your-partner",
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "partner": "a",
      "friend": "a",
      "significant other": "a"
    },
    "id": "boyfriend-girlfriend",
    "inconsiderate": {
      "girlfriend": "female",
      "boyfriend": "male"
    },
    "note": "Source: https://www.bustle.com/articles/108321-6-reasons-to-refer-to-your-significant-other-as-your-partner",
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "partners": "a",
      "friends": "a",
      "significant others": "a"
    },
    "id": "boyfriends-girlfriends",
    "inconsiderate": {
      "girlfriends": "female",
      "boyfriends": "male"
    },
    "note": "Source: https://www.bustle.com/articles/108321-6-reasons-to-refer-to-your-significant-other-as-your-partner",
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "childhood": "a"
    },
    "id": "boyhood-girlhood",
    "inconsiderate": {
      "girlhood": "female",
      "boyhood": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "childish": "a"
    },
    "id": "boyish-girly",
    "inconsiderate": {
      "girly": "female",
      "girlish": "female",
      "boyish": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "journeyperson": "a"
    },
    "id": "journeyman-journeywoman",
    "inconsiderate": {
      "journeywoman": "female",
      "journeyman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "journeypersons": "a"
    },
    "id": "journeymen-journeywomen",
    "inconsiderate": {
      "journeywomen": "female",
      "journeymen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "godparent": "a",
      "elder": "a",
      "patron": "a"
    },
    "id": "godfather-godmother",
    "inconsiderate": {
      "godmother": "female",
      "patroness": "female",
      "godfather": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "grandchild": "a"
    },
    "id": "granddaughter-grandson",
    "inconsiderate": {
      "granddaughter": "female",
      "grandson": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "grandchildren": "a"
    },
    "id": "granddaughters-grandsons",
    "inconsiderate": {
      "granddaughters": "female",
      "grandsons": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "ancestor": "a"
    },
    "id": "forefather-foremother",
    "inconsiderate": {
      "foremother": "female",
      "forefather": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "ancestors": "a"
    },
    "id": "forefathers-foremothers",
    "inconsiderate": {
      "foremothers": "female",
      "forefathers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "grandparent": "a",
      "ancestor": "a"
    },
    "id": "gramps-granny",
    "inconsiderate": {
      "granny": "female",
      "grandma": "female",
      "grandmother": "female",
      "grandpappy": "male",
      "granddaddy": "male",
      "gramps": "male",
      "grandpa": "male",
      "grandfather": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "grandparents": "a",
      "ancestors": "a"
    },
    "id": "grandfathers-grandmothers",
    "inconsiderate": {
      "grandmothers": "female",
      "grandfathers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "spouse": "a",
      "newlywed": "a"
    },
    "id": "bride-groom",
    "inconsiderate": {
      "bride": "female",
      "groom": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "sibling": "a"
    },
    "id": "brother-sister",
    "inconsiderate": {
      "sister": "female",
      "brother": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "siblings": "a"
    },
    "id": "brothers-sisters",
    "inconsiderate": {
      "sisters": "female",
      "brothers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "camera operator": "a",
      "camera person": "a"
    },
    "id": "cameraman-camerawoman",
    "inconsiderate": {
      "camerawoman": "female",
      "cameraman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "camera operators": "a"
    },
    "id": "cameramen-camerawomen",
    "inconsiderate": {
      "camerawomen": "female",
      "cameramen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "troglodyte": "a",
      "hominidae": "a"
    },
    "id": "caveman-cavewoman",
    "inconsiderate": {
      "cavewoman": "female",
      "caveman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "troglodytae": "a",
      "troglodyti": "a",
      "troglodytes": "a",
      "hominids": "a"
    },
    "id": "cavemen-cavewomen",
    "inconsiderate": {
      "cavewomen": "female",
      "cavemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "clergyperson": "a",
      "clergy": "a",
      "cleric": "a"
    },
    "id": "clergyman-clergywoman",
    "inconsiderate": {
      "clergywoman": "female",
      "clergyman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "clergies": "a",
      "clerics": "a"
    },
    "id": "clergymen-clergywomen",
    "inconsiderate": {
      "clergywomen": "female",
      "clergymen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "council member": "a"
    },
    "id": "councilman-councilwoman",
    "inconsiderate": {
      "councilwoman": "female",
      "councilman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "council members": "a"
    },
    "id": "councilmen-councilwomen",
    "inconsiderate": {
      "councilwomen": "female",
      "councilmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "country person": "a"
    },
    "id": "countryman-countrywoman",
    "inconsiderate": {
      "countrywoman": "female",
      "countryman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "country folk": "a"
    },
    "id": "countrymen-countrywomen",
    "inconsiderate": {
      "countrywomen": "female",
      "countrymen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "artisan": "a",
      "craftsperson": "a",
      "skilled worker": "a"
    },
    "id": "handyman-handywoman",
    "inconsiderate": {
      "handywoman": "female",
      "craftswoman": "female",
      "handyman": "male",
      "craftsman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "presenter": "a",
      "entertainer": "a",
      "emcee": "a"
    },
    "id": "host-hostess",
    "inconsiderate": {
      "hostess": "female",
      "host": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "presenters": "a",
      "entertainers": "a",
      "emcees": "a"
    },
    "id": "hostesses-hosts",
    "inconsiderate": {
      "hostesses": "female",
      "hosts": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "artisans": "a",
      "craftspersons": "a",
      "skilled workers": "a"
    },
    "id": "handymen-handywomen",
    "inconsiderate": {
      "handywomen": "female",
      "craftswomen": "female",
      "handymen": "male",
      "craftsmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "guillotine": "a"
    },
    "id": "hangman-hangwoman",
    "inconsiderate": {
      "hangwoman": "female",
      "hangman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "guillotines": "a"
    },
    "id": "hangmen-hangwomen",
    "inconsiderate": {
      "hangwomen": "female",
      "hangmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "sidekick": "a"
    },
    "id": "henchman-henchwoman",
    "inconsiderate": {
      "henchwoman": "female",
      "henchman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "sidekicks": "a"
    },
    "id": "henchmen-henchwomen",
    "inconsiderate": {
      "henchwomen": "female",
      "henchmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "role-model": "a",
      "mentor": "a"
    },
    "id": "hero-heroine",
    "inconsiderate": {
      "heroine": "female",
      "hero": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "role-models": "a",
      "mentor": "a"
    },
    "id": "heroes-heroines",
    "inconsiderate": {
      "heroines": "female",
      "heroes": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "parental": "a",
      "warm": "a",
      "intimate": "a"
    },
    "id": "maternal-paternal",
    "inconsiderate": {
      "maternal": "female",
      "paternal": "male",
      "fraternal": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "parental": "a"
    },
    "id": "maternity-paternity",
    "inconsiderate": {
      "maternity": "female",
      "paternity": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "parents": "a"
    },
    "id": "dads-moms",
    "inconsiderate": {
      "mamas": "female",
      "mothers": "female",
      "moms": "female",
      "mums": "female",
      "mommas": "female",
      "mommies": "female",
      "papas": "male",
      "fathers": "male",
      "dads": "male",
      "daddies": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "parent": "a"
    },
    "id": "dad-mom",
    "inconsiderate": {
      "mama": "female",
      "mother": "female",
      "mom": "female",
      "mum": "female",
      "momma": "female",
      "mommy": "female",
      "papa": "male",
      "father": "male",
      "dad": "male",
      "pop": "male",
      "daddy": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "child": "a"
    },
    "id": "daughter-son",
    "inconsiderate": {
      "daughter": "female",
      "son": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "children": "a"
    },
    "id": "daughters-sons",
    "inconsiderate": {
      "daughters": "female",
      "sons": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "concierge": "a"
    },
    "id": "doorman-doorwoman",
    "inconsiderate": {
      "doorwoman": "female",
      "doorman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "concierges": "a"
    },
    "id": "doormen-doorwomen",
    "inconsiderate": {
      "doorwomen": "female",
      "doormen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "humanly": "a",
      "mature": "a"
    },
    "id": "feminin-manly",
    "inconsiderate": {
      "feminin": "female",
      "dudely": "male",
      "manly": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "humans": "a"
    },
    "id": "females-males",
    "inconsiderate": {
      "females": "female",
      "males": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "ruler": "a"
    },
    "id": "king-queen",
    "inconsiderate": {
      "empress": "female",
      "queen": "female",
      "emperor": "male",
      "king": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "rulers": "a"
    },
    "id": "kings-queens",
    "inconsiderate": {
      "empresses": "female",
      "queens": "female",
      "emperors": "male",
      "kings": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "jumbo": "a",
      "gigantic": "a"
    },
    "id": "kingsize-queensize",
    "inconsiderate": {
      "queensize": "female",
      "kingsize": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "power behind the throne": "a"
    },
    "id": "kingmaker-queenmaker",
    "inconsiderate": {
      "queenmaker": "female",
      "kingmaker": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "civilian": "a"
    },
    "id": "layman-laywoman",
    "inconsiderate": {
      "laywoman": "female",
      "layman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "civilians": "a"
    },
    "id": "laymen-laywomen",
    "inconsiderate": {
      "laywomen": "female",
      "laymen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "official": "a",
      "owner": "a",
      "expert": "a",
      "superior": "a",
      "chief": "a",
      "ruler": "a"
    },
    "id": "dame-lord",
    "inconsiderate": {
      "dame": "female",
      "lord": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "officials": "a",
      "chiefs": "a",
      "rulers": "a"
    },
    "id": "dames-lords",
    "inconsiderate": {
      "dames": "female",
      "lords": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "adulthood": "a",
      "personhood": "a",
      "maturity": "a"
    },
    "id": "manhood-womanhood",
    "inconsiderate": {
      "womanhood": "female",
      "masculinity": "male",
      "manhood": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "humanity": "a"
    },
    "id": "femininity-manliness",
    "inconsiderate": {
      "femininity": "female",
      "manliness": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "shooter": "a"
    },
    "id": "marksman-markswoman",
    "inconsiderate": {
      "markswoman": "female",
      "marksman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "shooters": "a"
    },
    "id": "marksmen-markswomen",
    "inconsiderate": {
      "markswomen": "female",
      "marksmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "intermediary": "a",
      "go-between": "a"
    },
    "id": "middleman-middlewoman",
    "inconsiderate": {
      "middlewoman": "female",
      "middleman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "intermediaries": "a",
      "go-betweens": "a"
    },
    "id": "middlemen-middlewomen",
    "inconsiderate": {
      "middlewomen": "female",
      "middlemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "milk person": "a"
    },
    "id": "milkman-milkwoman",
    "inconsiderate": {
      "milkwoman": "female",
      "milkman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "milk people": "a"
    },
    "id": "milkmen-milkwomen",
    "inconsiderate": {
      "milkwomen": "female",
      "milkmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "nibling": "a",
      "sibling’s child": "a"
    },
    "id": "nephew-niece",
    "inconsiderate": {
      "niece": "female",
      "nephew": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "niblings": "a",
      "sibling’s children": "a"
    },
    "id": "nephews-nieces",
    "inconsiderate": {
      "nieces": "female",
      "nephews": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "noble": "a"
    },
    "id": "nobleman-noblewoman",
    "inconsiderate": {
      "noblewoman": "female",
      "nobleman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "nobles": "a"
    },
    "id": "noblemen-noblewomen",
    "inconsiderate": {
      "noblewomen": "female",
      "noblemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "notary": "a",
      "consumer advocate": "a",
      "trouble shooter": "a",
      "omsbudperson": "a",
      "mediator": "a"
    },
    "id": "ombudsman-ombudswoman",
    "inconsiderate": {
      "ombudswoman": "female",
      "ombudsman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "notaries": "a",
      "omsbudpersons": "a",
      "omsbudpeople": "a",
      "mediators": "a"
    },
    "id": "ombudsmen-ombudswomen",
    "inconsiderate": {
      "ombudswomen": "female",
      "ombudsmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "heir": "a"
    },
    "id": "prince-princess",
    "inconsiderate": {
      "princess": "female",
      "prince": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "heirs": "a"
    },
    "id": "princes-princesses",
    "inconsiderate": {
      "princesses": "female",
      "princes": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fairy": "a"
    },
    "id": "sandman-sandwoman",
    "inconsiderate": {
      "sandwoman": "female",
      "sandman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "fairies": "a"
    },
    "id": "sandmen-sandwomen",
    "inconsiderate": {
      "sandwomen": "female",
      "sandmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "promoter": "a"
    },
    "id": "showman-showwoman",
    "inconsiderate": {
      "showwoman": "female",
      "showman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "promoters": "a"
    },
    "id": "showmen-showwomen",
    "inconsiderate": {
      "showwomen": "female",
      "show women": "female",
      "showmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "astronaut": "a"
    },
    "id": "spaceman-spacewoman",
    "inconsiderate": {
      "spacewoman": "female",
      "spaceman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "astronauts": "a"
    },
    "id": "spacemen-spacewomen",
    "inconsiderate": {
      "spacewomen": "female",
      "spacemen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "speaker": "a",
      "spokesperson": "a",
      "representative": "a"
    },
    "id": "spokesman-spokeswoman",
    "inconsiderate": {
      "spokeswoman": "female",
      "spokesman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "speakers": "a",
      "spokespersons": "a"
    },
    "id": "spokesmen-spokeswomen",
    "inconsiderate": {
      "spokeswomen": "female",
      "spokesmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "athlete": "a",
      "sports person": "a"
    },
    "id": "sportsman-sportswoman",
    "inconsiderate": {
      "sportswoman": "female",
      "sportsman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "athletes": "a",
      "sports persons": "a"
    },
    "id": "sportsmen-sportswomen",
    "inconsiderate": {
      "sportswomen": "female",
      "sportsmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "senator": "a"
    },
    "id": "statesman-stateswoman",
    "inconsiderate": {
      "stateswoman": "female",
      "statesman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "step-sibling": "a"
    },
    "id": "stepbrother-stepsister",
    "inconsiderate": {
      "stepsister": "female",
      "stepbrother": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "step-siblings": "a"
    },
    "id": "stepbrothers-stepsisters",
    "inconsiderate": {
      "stepsisters": "female",
      "stepbrothers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "step-parent": "a"
    },
    "id": "stepdad-stepmom",
    "inconsiderate": {
      "stepmom": "female",
      "stepmother": "female",
      "stepdad": "male",
      "stepfather": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "step-parents": "a"
    },
    "id": "stepfathers-stepmothers",
    "inconsiderate": {
      "stepmothers": "female",
      "stepfathers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "titan": "a"
    },
    "id": "superman-superwoman",
    "inconsiderate": {
      "superwoman": "female",
      "superman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "titans": "a"
    },
    "id": "supermen-superwomen",
    "inconsiderate": {
      "superwomen": "female",
      "supermen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "inhumane": "a"
    },
    "id": "unmanly-unwomanly",
    "inconsiderate": {
      "unwomanly": "female",
      "unwomenly": "female",
      "unmanly": "male",
      "unmenly": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "watcher": "a"
    },
    "id": "watchman-watchwoman",
    "inconsiderate": {
      "watchwoman": "female",
      "watchman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "watchers": "a"
    },
    "id": "watchmen-watchwomen",
    "inconsiderate": {
      "watchwomen": "female",
      "watchmen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "weather forecaster": "a",
      "meteorologist": "a"
    },
    "id": "weatherman-weatherwoman",
    "inconsiderate": {
      "weatherwoman": "female",
      "weatherman": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "weather forecasters": "a",
      "meteorologists": "a"
    },
    "id": "weathermen-weatherwomen",
    "inconsiderate": {
      "weatherwomen": "female",
      "weathermen": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "bereaved": "a"
    },
    "id": "widow-widower",
    "inconsiderate": {
      "widow": "female",
      "widows": "female",
      "widower": "male",
      "widowers": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "female",
      "male"
    ],
    "considerate": {
      "own person": "a"
    },
    "id": "own-man-own-woman",
    "inconsiderate": {
      "own woman": "female",
      "own man": "male"
    },
    "type": "or"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "french": "a",
      "the french": "a"
    },
    "id": "frenchmen",
    "inconsiderate": {
      "frenchmen": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "courteous": "a",
      "cultured": "a"
    },
    "id": "ladylike",
    "inconsiderate": {
      "ladylike": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "resolutely": "a",
      "bravely": "a"
    },
    "id": "like-a-man",
    "inconsiderate": {
      "like a man": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "birth name": "a"
    },
    "id": "maiden-name",
    "inconsiderate": {
      "maiden name": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "first voyage": "a"
    },
    "id": "maiden-voyage",
    "inconsiderate": {
      "maiden voyage": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "first flight": "a"
    },
    "id": "maiden-flight",
    "inconsiderate": {
      "maiden flight": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "strong enough": "a"
    },
    "id": "man-enough",
    "inconsiderate": {
      "man enough": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "upstaging": "a",
      "competitiveness": "a"
    },
    "id": "oneupmanship",
    "inconsiderate": {
      "oneupmanship": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "ms.": "a"
    },
    "id": "mrs-",
    "inconsiderate": {
      "miss.": "female",
      "mrs.": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "manufactured": "a",
      "artificial": "a",
      "synthetic": "a",
      "machine-made": "a",
      "constructed": "a"
    },
    "id": "manmade",
    "inconsiderate": {
      "manmade": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "dynamo": "a"
    },
    "id": "man-of-action",
    "inconsiderate": {
      "man of action": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "scholar": "a",
      "writer": "a",
      "literary figure": "a"
    },
    "id": "man-of-letters",
    "inconsiderate": {
      "man of letters": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "sophisticate": "a"
    },
    "id": "man-of-the-world",
    "inconsiderate": {
      "man of the world": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "camaraderie": "a",
      "community": "a",
      "organization": "a"
    },
    "id": "fellowship",
    "inconsiderate": {
      "fellowship": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "first-year student": "a",
      "fresher": "a"
    },
    "id": "freshman",
    "inconsiderate": {
      "freshman": "male",
      "freshwoman": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "quality construction": "a",
      "expertise": "a"
    },
    "id": "workmanship",
    "inconsiderate": {
      "workmanship": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "homemaker": "a",
      "homeworker": "a"
    },
    "id": "housewife",
    "inconsiderate": {
      "housewife": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "homemakers": "a",
      "homeworkers": "a"
    },
    "id": "housewives",
    "inconsiderate": {
      "housewives": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "female"
    ],
    "considerate": {
      "loving": "a",
      "warm": "a",
      "nurturing": "a"
    },
    "id": "motherly",
    "inconsiderate": {
      "motherly": "female"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "human resources": "a",
      "workforce": "a",
      "personnel": "a",
      "staff": "a",
      "labor": "a",
      "labor force": "a",
      "staffing": "a",
      "combat personnel": "a"
    },
    "id": "manpower",
    "inconsiderate": {
      "manpower": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "emcee": "a",
      "moderator": "a",
      "convenor": "a"
    },
    "id": "master-of-ceremonies",
    "inconsiderate": {
      "master of ceremonies": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "skilled": "a",
      "authoritative": "a",
      "commanding": "a"
    },
    "id": "masterful",
    "inconsiderate": {
      "masterful": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "genius": "a",
      "creator": "a",
      "instigator": "a",
      "oversee": "a",
      "launch": "a",
      "originate": "a"
    },
    "id": "mastermind",
    "inconsiderate": {
      "mastermind": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "work of genius": "a",
      "chef d’oeuvre": "a"
    },
    "id": "masterpiece",
    "inconsiderate": {
      "masterpiece": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "vision": "a",
      "comprehensive plan": "a"
    },
    "id": "masterplan",
    "inconsiderate": {
      "masterplan": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "trump card": "a",
      "stroke of genius": "a"
    },
    "id": "masterstroke",
    "inconsiderate": {
      "masterstroke": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "fanatic": "a",
      "zealot": "a",
      "enthusiast": "a"
    },
    "id": "madman",
    "inconsiderate": {
      "madman": "male",
      "mad man": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "fanatics": "a",
      "zealots": "a",
      "enthusiasts": "a"
    },
    "id": "madmen",
    "inconsiderate": {
      "madmen": "male",
      "mad men": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "humankind": "a"
    },
    "id": "mankind",
    "inconsiderate": {
      "mankind": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "staff hour": "a",
      "hour of work": "a"
    },
    "id": "manhour",
    "inconsiderate": {
      "manhour": "male",
      "man hour": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "male"
    ],
    "considerate": {
      "staff hours": "a",
      "hours of work": "a",
      "hours of labor": "a",
      "hours": "a"
    },
    "id": "manhours",
    "inconsiderate": {
      "manhours": "male",
      "man hours": "male"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "staffed": "a",
      "crewed": "a",
      "piloted": "a"
    },
    "id": "manned",
    "inconsiderate": {
      "manned": "a"
    },
    "note": "Using gender neutral language means users will help to break up gender stereotypes.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "robotic": "a",
      "automated": "a"
    },
    "id": "unmanned",
    "inconsiderate": {
      "unmanned": "a"
    },
    "note": "Using gender neutral language means users will help to break up gender stereotypes.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "whining": "a",
      "complaining": "a",
      "crying": "a"
    },
    "id": "moaning",
    "inconsiderate": {
      "bitching": "a",
      "moaning": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "whine": "a",
      "complain": "a",
      "cry": "a"
    },
    "id": "moan",
    "inconsiderate": {
      "bitch": "a",
      "moan": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "tank top": "a",
      "sleeveless undershirt": "a"
    },
    "id": "wifebeater",
    "inconsiderate": {
      "wife beater": "a",
      "wifebeater": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "ancient civilization": "a",
      "ancient people": "a"
    },
    "id": "ancient-man",
    "inconsiderate": {
      "ancient man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "author": "a",
      "writer": "a"
    },
    "id": "authoress",
    "inconsiderate": {
      "authoress": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "average consumer": "a",
      "average household": "a",
      "average homemaker": "a"
    },
    "id": "average-housewife",
    "inconsiderate": {
      "average housewife": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "average person": "a"
    },
    "id": "average-man",
    "inconsiderate": {
      "average man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "average wage earner": "a",
      "average taxpayer": "a"
    },
    "id": "average-working-man",
    "inconsiderate": {
      "average working man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "aviator": "a"
    },
    "id": "aviatrix",
    "inconsiderate": {
      "aviatrix": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "the human family": "a"
    },
    "id": "brotherhood-of-man",
    "inconsiderate": {
      "brotherhood of man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "model": "a"
    },
    "id": "calendar-girl",
    "inconsiderate": {
      "calendar girl": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "escort": "a",
      "prostitute": "a",
      "sex worker": "a"
    },
    "id": "call-girl",
    "inconsiderate": {
      "call girl": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "cleric": "a",
      "practicing Christian": "a",
      "pillar of the Church": "a"
    },
    "id": "churchman",
    "inconsiderate": {
      "churchman": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "english coordinator": "a",
      "senior teacher of english": "a"
    },
    "id": "english-master",
    "inconsiderate": {
      "english master": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "the english": "a"
    },
    "id": "englishmen",
    "inconsiderate": {
      "englishmen": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "executor": "a"
    },
    "id": "executrix",
    "inconsiderate": {
      "executrix": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "founder of": "a"
    },
    "id": "father-of-*",
    "inconsiderate": {
      "father of *": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "the founders": "a",
      "founding leaders": "a",
      "forebears": "a"
    },
    "id": "founding-father",
    "inconsiderate": {
      "founding father": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "house worker": "a",
      "domestic help": "a"
    },
    "id": "housemaid",
    "inconsiderate": {
      "housemaid": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "industrial civilization": "a",
      "industrial people": "a"
    },
    "id": "industrial-man",
    "inconsiderate": {
      "industrial man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "doctor": "a"
    },
    "id": "lady-doctor",
    "inconsiderate": {
      "lady doctor": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "lead": "a"
    },
    "id": "leading-lady",
    "inconsiderate": {
      "leading lady": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "virgin": "a"
    },
    "id": "maiden",
    "inconsiderate": {
      "maiden": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "first race": "a"
    },
    "id": "maiden-race",
    "inconsiderate": {
      "maiden race": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "first speech": "a"
    },
    "id": "maiden-speech",
    "inconsiderate": {
      "maiden speech": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "staff a desk": "a"
    },
    "id": "man-a-desk",
    "inconsiderate": {
      "man a desk": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "ordinary citizen": "a",
      "typical person": "a",
      "average person": "a"
    },
    "id": "man-in-the-street",
    "inconsiderate": {
      "man in the street": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "farmer": "a",
      "rural worker": "a",
      "grazier": "a",
      "landowner": "a",
      "rural community": "a",
      "country people": "a",
      "country folk": "a"
    },
    "id": "man-of-the-land",
    "inconsiderate": {
      "man of the land": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "a faithful dog": "a"
    },
    "id": "mans-best-friend",
    "inconsiderate": {
      "mans best friend": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "staff the booth": "a"
    },
    "id": "man-the-booth",
    "inconsiderate": {
      "man the booth": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "answer the phones": "a"
    },
    "id": "man-the-phones",
    "inconsiderate": {
      "man the phones": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "a demanding task": "a",
      "a big job": "a"
    },
    "id": "mansized-task",
    "inconsiderate": {
      "mansized task": "a",
      "man sized task": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "pass key": "a",
      "original": "a"
    },
    "id": "master-key",
    "inconsiderate": {
      "master key": "a",
      "master copy": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "grand scheme": "a",
      "guiding principles": "a"
    },
    "id": "master-plan",
    "inconsiderate": {
      "master plan": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "become skilled": "a"
    },
    "id": "master-the-art",
    "inconsiderate": {
      "master the art": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "scientists": "a"
    },
    "id": "men-of-science",
    "inconsiderate": {
      "men of science": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "birthing nurse": "a"
    },
    "id": "midwife",
    "inconsiderate": {
      "midwife": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "modern civilization": "a",
      "modern people": "a"
    },
    "id": "modern-man",
    "inconsiderate": {
      "modern man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "unoccupied territory": "a",
      "wasteland": "a",
      "deathtrap": "a"
    },
    "id": "no-mans-land",
    "inconsiderate": {
      "no mans land": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "administrative staff": "a"
    },
    "id": "office-girls",
    "inconsiderate": {
      "office girls": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "poet": "a"
    },
    "id": "poetess",
    "inconsiderate": {
      "poetess": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "railway worker": "a"
    },
    "id": "railwayman",
    "inconsiderate": {
      "railwayman": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "fair": "a",
      "sporting": "a"
    },
    "id": "sportsmanlike",
    "inconsiderate": {
      "sportsmanlike": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "fairness": "a",
      "good humor": "a",
      "sense of fair play": "a"
    },
    "id": "sportsmanship",
    "inconsiderate": {
      "sportsmanship": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "diplomatic": "a"
    },
    "id": "statesmanlike",
    "inconsiderate": {
      "statesmanlike": "a",
      "statesman like": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "cattle worker": "a",
      "farmhand": "a",
      "drover": "a"
    },
    "id": "stockman",
    "inconsiderate": {
      "stockman": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "service entrance": "a"
    },
    "id": "tradesmans-entrance",
    "inconsiderate": {
      "tradesmans entrance": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "tax commissioner": "a",
      "tax office": "a",
      "tax collector": "a"
    },
    "id": "tax-man",
    "inconsiderate": {
      "tax man": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "usher": "a"
    },
    "id": "usherette",
    "inconsiderate": {
      "usherette": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "lawyer": "a"
    },
    "id": "woman-lawyer",
    "inconsiderate": {
      "woman lawyer": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "painter": "a"
    },
    "id": "woman-painter",
    "inconsiderate": {
      "woman painter": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "wage or salary earning woman": "a",
      "two-income family": "a"
    },
    "id": "working-wife",
    "inconsiderate": {
      "working mother": "a",
      "working wife": "a"
    },
    "note": "Source: https://radyananda.wordpress.com/2009/06/06/nonsexist-alternative-language-handbook-for-conscious-writers/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "gay": "a",
      "gay man": "a",
      "lesbian": "a",
      "gay person/people": "a"
    },
    "id": "homosexual",
    "inconsiderate": {
      "homosexual": "a"
    },
    "note": "This term has a clinical history and is used to imply LGBTQ+ people are diseased or psychologically/emotionally disordered (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "relationship": "a"
    },
    "id": "homosexual-relations",
    "inconsiderate": {
      "homosexual relations": "a",
      "homosexual relationship": "a"
    },
    "note": "Avoid labeling something as LGBTQ+ unless you would call the same thing “straight” (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "couple": "a"
    },
    "id": "homosexual-couple",
    "inconsiderate": {
      "homosexual couple": "a"
    },
    "note": "Avoid labeling something as LGBTQ+ unless you would call the same thing “straight” (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sexual orientation": "a",
      "orientation": "a"
    },
    "id": "sexual-preference",
    "inconsiderate": {
      "sexual preference": "a"
    },
    "note": "Implies that being LGBTQ+ is a choice (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "gay lives": "a",
      "gay/lesbian lives": "a"
    },
    "id": "gay-lifestyle",
    "inconsiderate": {
      "gay lifestyle": "a",
      "homosexual lifestyle": "a"
    },
    "note": "Implies that being LGBTQ+ is a choice (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "gay issues": "a"
    },
    "id": "gay-agenda",
    "inconsiderate": {
      "gay agenda": "a",
      "homosexual agenda": "a"
    },
    "note": "Used by anti-LGBTQ+ extremists to create a climate of fear around LGBTQ+ issues (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "equal rights": "a",
      "civil rights for gay people": "a"
    },
    "id": "gay-rights",
    "inconsiderate": {
      "special rights": "a",
      "gay rights": "a"
    },
    "note": "LGBTQ+ rights are human rights (source: https://www.glaad.org/reference/style)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "gay": "a"
    },
    "id": "fag",
    "inconsiderate": {
      "fag": "a",
      "faggot": "a",
      "dyke": "a",
      "homo": "a",
      "sodomite": "a"
    },
    "note": "Derogatory terms for LGBTQ+ people are offensive (source: https://www.glaad.org/reference/offensive)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "bisexual": "a"
    },
    "id": "bi",
    "inconsiderate": {
      "bi": "a"
    },
    "note": "Avoid using slang shorthand (source: https://www.glaad.org/reference/style)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "gay marriage": "a",
      "same-sex marriage": "a"
    },
    "id": "homosexual-marriage",
    "inconsiderate": {
      "homosexual marriage": "a"
    },
    "note": "Homosexual has a clinical history and is used to imply LGBTQ+ people are diseased or psychologically/emotionally disordered (source: https://www.glaad.org/reference/style)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "transgender": "a"
    },
    "id": "tranny",
    "inconsiderate": {
      "tranny": "a"
    },
    "note": "Derogatory terms for LGBTQ+ people are offensive (source: https://www.glaad.org/reference/style)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "cross-dresser": "a"
    },
    "id": "transvestite",
    "inconsiderate": {
      "transvestite": "a"
    },
    "note": "Avoid using outdated / offensive terms (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "transition": "a",
      "gender confirmation surgery": "a"
    },
    "id": "sexchange",
    "inconsiderate": {
      "sexchange": "a",
      "sex change": "a"
    },
    "note": "Avoid overemphasizing surgery when discussing transgender people or the process of transition - it’s not a necessary component (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "sex reassignment surgery": "a",
      "gender confirmation surgery": "a"
    },
    "id": "sex-change-operation",
    "inconsiderate": {
      "sex change operation": "a"
    },
    "note": "Shift focus away from the assigned sex and towards the identified gender (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "transgender people": "a"
    },
    "id": "transgenders",
    "inconsiderate": {
      "transgenders": "a"
    },
    "note": "Transgender should be used as an adjective, not as a noun (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "transgender": "a"
    },
    "id": "transgendered",
    "inconsiderate": {
      "transgendered": "a"
    },
    "note": "Transgender is already an adjective (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "being transgender": "a",
      "the movement for transgender equality": "a"
    },
    "id": "transgenderism",
    "inconsiderate": {
      "transgenderism": "a"
    },
    "note": "This is a term used by anti-transgender activists to dehumanize transgender people and reduce who they are to a condition (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "assigned male at birth": "a",
      "designated male at birth": "a"
    },
    "id": "born-a-man",
    "inconsiderate": {
      "biologically male": "a",
      "born a man": "a",
      "genetically male": "a"
    },
    "note": "Assigned birth gender is complicated; gender identity is more than what your parents decided you were at birth",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "assigned female at birth": "a",
      "designated female at birth": "a"
    },
    "id": "born-a-woman",
    "inconsiderate": {
      "biologically female": "a",
      "born a woman": "a",
      "genetically female": "a"
    },
    "note": "Assigned birth gender is complicated; gender identity is more than what your parents decided you were at birth",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "non-discrimination law": "a",
      "non-discrimination ordinance": "a"
    },
    "id": "bathroom-bill",
    "inconsiderate": {
      "bathroom bill": "a"
    },
    "note": "A term created and used by far-right extremists to oppose nondiscrimination laws that protect transgender people (source: https://www.glaad.org/reference/transgender)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "intersex": "a"
    },
    "id": "hermaphroditic",
    "inconsiderate": {
      "hermaphroditic": "a",
      "pseudohermaphroditic": "a",
      "pseudo hermaphroditic": "a"
    },
    "note": "These terms are stigmatizing to patients and their families because intersex status is more complicated than the mere presence or absence of certain gonadal tissues (source: http://www.isna.org/node/979)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person who is intersex": "a",
      "person": "a",
      "intersex person": "a"
    },
    "id": "hermaphrodite",
    "inconsiderate": {
      "hermaphrodite": "a",
      "pseudohermaphrodite": "a",
      "pseudo hermaphrodite": "a"
    },
    "note": "These terms are stigmatizing to patients and their families because intersex status is more complicated than the mere presence or absence of certain gonadal tissues (source: http://www.isna.org/node/979)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "transgender person": "a",
      "person": "a"
    },
    "id": "heshe",
    "inconsiderate": {
      "shemale": "a",
      "she male": "a",
      "heshe": "a",
      "shehe": "a"
    },
    "note": "This word dehumanizes transgender people (source: https://www.reddit.com/r/asktransgender/comments/23wbq1/is_the_term_shemale_seen_as_offensive/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "pronoun": "a",
      "pronouns": "a"
    },
    "id": "gender-pronoun",
    "inconsiderate": {
      "preferred pronoun": "a",
      "preferred pronouns": "a",
      "gender pronoun": "a",
      "gender pronouns": "a"
    },
    "note": "Preferred pronoun sounds like it is optional to use someone's correct pronoun (source: https://www.selfdefined.app/definitions/pronouns/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "muslim": "a",
      "person of Islamic faith": "a",
      "fanatic": "a",
      "zealot": "a",
      "follower of islam": "a",
      "follower of the islamic faith": "a"
    },
    "id": "islamist",
    "inconsiderate": {
      "islamist": "a"
    },
    "note": "Source: https://www.usnews.com/news/newsgram/articles/2013/04/04/the-associated-press-revises-islamist-another-politically-charged-term",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "muslims": "a",
      "people of Islamic faith": "a",
      "fanatics": "a",
      "zealots": "a"
    },
    "id": "islamists",
    "inconsiderate": {
      "islamists": "a"
    },
    "note": "Source: https://www.usnews.com/news/newsgram/articles/2013/04/04/the-associated-press-revises-islamist-another-politically-charged-term",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "primary": "a",
      "lead": "a",
      "hub": "a",
      "reference": "a"
    },
    "id": "master",
    "inconsiderate": {
      "master": "a"
    },
    "note": "Avoid using the term `master`; these suggestions are for the computer term, but there are better alternatives for other cases too",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "primaries": "a",
      "hubs": "a",
      "references": "a"
    },
    "id": "masters",
    "inconsiderate": {
      "masters": "a"
    },
    "note": "Avoid using the term `master`; these suggestions are for the computer term, but there are better alternatives for other cases too",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "secondary": "a",
      "worker": "a",
      "replica": "a",
      "node": "a"
    },
    "id": "slave",
    "inconsiderate": {
      "slave": "a"
    },
    "note": "Avoid using the term `slave`; these suggestions are for the computer term, but there are better alternatives for other cases too",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "secondaries": "a",
      "workers": "a",
      "replicas": "a",
      "nodes": "a"
    },
    "id": "slaves",
    "inconsiderate": {
      "slaves": "a"
    },
    "note": "Avoid using the term `slave`; these suggestions are for the computer term, but there are better alternatives for other cases too",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "unethical hacker": "a",
      "malicious actor": "a"
    },
    "id": "blackhat",
    "inconsiderate": {
      "blackhat": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "ethical hacker": "a",
      "security researcher": "a"
    },
    "id": "whitehat",
    "inconsiderate": {
      "whitehat": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Inuit": "a"
    },
    "id": "eskimo",
    "inconsiderate": {
      "eskimo": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Inuits": "a"
    },
    "id": "eskimos",
    "inconsiderate": {
      "eskimos": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Asian person": "a"
    },
    "id": "oriental",
    "inconsiderate": {
      "oriental": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Asian people": "a"
    },
    "id": "orientals",
    "inconsiderate": {
      "orientals": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "person of color": "a",
      "people of color": "a"
    },
    "id": "nonwhite",
    "inconsiderate": {
      "nonwhite": "a",
      "non white": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "projects": "a",
      "urban": "a"
    },
    "id": "ghetto",
    "inconsiderate": {
      "ghetto": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Native American": "a"
    },
    "id": "redskin",
    "inconsiderate": {
      "red indian": "a",
      "pocahontas": "a",
      "redskin": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Native American People": "a"
    },
    "id": "redskins",
    "inconsiderate": {
      "red indians": "a",
      "redskins": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "favorite": "a",
      "inspiration": "a",
      "personal interest": "a",
      "personality type": "a"
    },
    "id": "totem",
    "inconsiderate": {
      "animal spirit": "a",
      "dream catcher": "a",
      "spirit animal": "a",
      "totem": "a"
    },
    "note": "Avoid using terms that oversimplify the complex and varied beliefs of indigenous religions. (source: https://www.worldreligionnews.com/opinion/spirit-animal-not-joke-oppression,https://www.spiralnature.com/spirituality/spirit-animal-cultural-appropriation)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "I haven’t seen you in a long time": "a",
      "it’s been a long time": "a"
    },
    "id": "long-time-no-see",
    "inconsiderate": {
      "long time no hear": "a",
      "long time no see": "a"
    },
    "note": "Avoid using phrases that implicitly mock people with limited knowledge of the English language. (source: https://www.npr.org/sections/codeswitch/2014/03/09/288300303/who-first-said-long-time-no-see-and-in-which-language)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "enemy territory": "a"
    },
    "id": "indian-country",
    "inconsiderate": {
      "Indian country": "a"
    },
    "note": "Avoid using phrases referring to the genocidal United States “Indian Removal” laws. (source: https://newsmaven.io/indiancountrytoday/archive/off-the-reservation-a-teachable-moment-nW1d7U0JRkOszhtg8N1V1A/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "disobey": "a",
      "endure": "a",
      "object to": "a",
      "oppose": "a",
      "resist": "a"
    },
    "id": "off-reserve",
    "inconsiderate": {
      "jump the reservation": "a",
      "off reserve": "a",
      "off the reservation": "a"
    },
    "note": "Avoid using phrases referring to the genocidal United States “Indian Removal” laws. (source: http://blog.nativepartnership.org/off-the-reservation/,https://www.wsj.com/articles/off-the-reservation-is-a-phrase-with-a-dark-past-1462552837,https://www.npr.org/sections/codeswitch/2014/06/29/326690947/should-saying-someone-is-off-the-reservation-be-off-limits,https://nowtoronto.com/news/native-references-and-terms-that-are-offensive-to-indigenous-people/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "defend": "a"
    },
    "id": "on-the-warpath",
    "inconsiderate": {
      "circle the wagons": "a",
      "on the warpath": "a"
    },
    "note": "Avoid using phrases referring to colonial stereotypes regarding Native Americans. (source: https://idioms.thefreedictionary.com/circle+the+wagons,https://idioms.thefreedictionary.com/go+on+the+warpath)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "too many chefs in the kitchen": "a",
      "too many cooks spoil the broth": "a"
    },
    "id": "too-many-chiefs",
    "inconsiderate": {
      "too many chiefs": "a"
    },
    "note": "Avoid using phrases referring to colonial stereotypes regarding Native Americans. (source: https://idioms.thefreedictionary.com/too+many+chiefs+and+not+enough+Indians)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "dissatisfied": "a",
      "frustrated": "a"
    },
    "id": "natives-are-restless",
    "inconsiderate": {
      "natives are restless": "a",
      "natives are becoming restless": "a",
      "natives are getting restless": "a",
      "natives are growing restless": "a"
    },
    "note": "Avoid using phrases referring to colonial stereotypes regarding indigenous peoples. (source: https://tvtropes.org/pmwiki/pmwiki.php/Main/TheNativesAreRestless)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "conference": "a",
      "gathering": "a",
      "meeting": "a"
    },
    "id": "powwow",
    "inconsiderate": {
      "pow wow": "a",
      "powwow": "a"
    },
    "note": "Avoid casually using this term, which refers to traditional indigenous celebration ceremonies that were banned by genocidal laws in the United States and Canada — Native people died fighting for this right. (source: https://twitter.com/chadloder/status/1203507070772793345,http://nativeappropriations.com/2012/09/paul-frank-offends-every-native-person-on-the-planet-with-fashion-night-out-dream-catchin-pow-wow.html,https://www.britannica.com/topic/powwow,https://nowtoronto.com/news/native-references-and-terms-that-are-offensive-to-indigenous-people/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "go back on one’s offer": "a"
    },
    "id": "indian-give",
    "inconsiderate": {
      "indian give": "a",
      "indian giver": "a"
    },
    "note": "Avoid using phrases referring to colonial stereotypes regarding Native Americans.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Filipinos": "a",
      "Filipino people": "a"
    },
    "id": "pinoys",
    "inconsiderate": {
      "pinoys": "a",
      "pinays": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Arabs": "a",
      "Middle Eastern People": "a"
    },
    "id": "towel-heads",
    "inconsiderate": {
      "towel heads": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Latinx": "a"
    },
    "id": "latino",
    "inconsiderate": {
      "latino": "a",
      "latina": "a"
    },
    "note": "Whenever possible, try to be gender inclusive.",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Japanese person": "a",
      "Japanese people": "a"
    },
    "id": "japs",
    "inconsiderate": {
      "japs": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Jewish person": "a"
    },
    "id": "hymie",
    "inconsiderate": {
      "shlomo": "a",
      "shyster": "a",
      "hymie": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "a person who is not Jewish": "a",
      "not Jewish": "a"
    },
    "id": "goy",
    "inconsiderate": {
      "goyim": "a",
      "goyum": "a",
      "goy": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "a Black person": "a"
    },
    "id": "spade",
    "inconsiderate": {
      "spade": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "Nomad": "a",
      "Traveler": "a",
      "Roma": "a",
      "Romani": "a"
    },
    "id": "gyp",
    "inconsiderate": {
      "gyppo": "a",
      "gypsy": "a",
      "Gipsy": "a",
      "gyp": "a"
    },
    "note": "Gypsy is insensitive, use Roma or Romani. They’re not Egyptian as the name suggests. (source: en.wikipedia.org/wiki/Romani_people#cite_ref-80)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "blocklist": "a",
      "wronglist": "a",
      "banlist": "a",
      "deny list": "a"
    },
    "id": "blacklist",
    "inconsiderate": {
      "blacklist": "a",
      "black list": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "blocklisted": "a",
      "wronglisted": "a",
      "banlisted": "a",
      "deny-listed": "a"
    },
    "id": "blacklisted",
    "inconsiderate": {
      "blacklisted": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "blocklisting": "a",
      "wronglisting": "a",
      "banlisting": "a",
      "deny-listing": "a"
    },
    "id": "blacklisting",
    "inconsiderate": {
      "blacklisting": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "passlist": "a",
      "alrightlist": "a",
      "safelist": "a",
      "allow list": "a"
    },
    "id": "whitelist",
    "inconsiderate": {
      "whitelist": "a",
      "white list": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "passlisted": "a",
      "alrightlisted": "a",
      "safelisted": "a",
      "allow-listed": "a"
    },
    "id": "whitelisted",
    "inconsiderate": {
      "whitelisted": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "passlisting": "a",
      "alrightlisting": "a",
      "safelisting": "a",
      "allow-listing": "a"
    },
    "id": "whitelisting",
    "inconsiderate": {
      "whitelisting": "a"
    },
    "note": "Replace racially-charged language with more accurate and inclusive words",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "simple": "a",
      "indigenous": "a",
      "hunter-gatherer": "a"
    },
    "id": "savage",
    "inconsiderate": {
      "primitive": "a",
      "savage": "a",
      "stone age": "a"
    },
    "note": "Avoid using terms that imply a group has not changed over time and that they are inferior",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "society": "a",
      "community": "a"
    },
    "id": "tribe",
    "inconsiderate": {
      "tribe": "a"
    },
    "note": "Avoid using terms that make some groups sound inferior",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "complex culture": "a"
    },
    "id": "sophisticated-culture",
    "inconsiderate": {
      "sophisticated culture": "a"
    },
    "note": "Avoid using terms that make some groups sound inferior. Replace “sophisticated” with a neutral term such as “complex”",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "complex technology": "a"
    },
    "id": "sophisticated-technology",
    "inconsiderate": {
      "sophisticated technology": "a"
    },
    "note": "Avoid using terms that make some groups sound inferior. Replace “sophisticated” with a neutral term such as “complex”",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "bug report": "a",
      "snapshot": "a"
    },
    "id": "bugreport",
    "inconsiderate": {
      "bugreport": "a"
    },
    "note": "Avoid using `bugreport`, as the word `bugre` is a slur in Brazilian Portuguese",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "legacy policy": "a",
      "legacy clause": "a",
      "deprecation policy": "a"
    },
    "id": "grandfather-clause",
    "inconsiderate": {
      "grandfather clause": "a",
      "grandfather policy": "a"
    },
    "note": "Avoid using phrases referring to racist United States “Jim Crow” laws. (source: https://en.wikipedia.org/wiki/Grandfather_clause#Origin)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "deprecate": "a"
    },
    "id": "grandfathering",
    "inconsiderate": {
      "grandfathering": "a"
    },
    "note": "Avoid using phrases referring to racist United States “Jim Crow” laws. (source: https://en.wikipedia.org/wiki/Grandfather_clause#Origin)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "deprecated": "a",
      "legacy": "a"
    },
    "id": "grandfathered",
    "inconsiderate": {
      "grandfathered": "a"
    },
    "note": "Avoid using phrases referring to racist United States “Jim Crow” laws. (source: https://en.wikipedia.org/wiki/Grandfather_clause#Origin)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "improve": "a"
    },
    "id": "make-*-great-again",
    "inconsiderate": {
      "make * great again": "a",
      "make * * great again": "a",
      "make * * * great again": "a",
      "make * * * * great again": "a",
      "make * * * * * great again": "a"
    },
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "died by suicide": "a"
    },
    "id": "committed-suicide",
    "inconsiderate": {
      "committed suicide": "a",
      "completed suicide": "a"
    },
    "note": "Source: https://www.afsp.org/news-events/for-the-media/reporting-on-suicide, https://www.speakingofsuicide.com/2013/04/13/language/",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "die by suicide": "a"
    },
    "id": "commit-suicide",
    "inconsiderate": {
      "commit suicide": "a",
      "complete suicide": "a",
      "successful suicide": "a"
    },
    "note": "Committing suicide is not successful/unsuccessful, that sends the wrong message (source: https://www.afsp.org/news-events/for-the-media/reporting-on-suicide, https://www.speakingofsuicide.com/2013/04/13/language/)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "rise in suicides": "a"
    },
    "id": "suicide-pact",
    "inconsiderate": {
      "suicide epidemic": "a",
      "epidemic of suicides": "a",
      "suicide pact": "a"
    },
    "note": "Using sensational words can cause copycat suicides or contagion (source: https://www.afsp.org/news-events/for-the-media/reporting-on-suicide)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "suicide attempt": "a",
      "attempted suicide": "a"
    },
    "id": "failed-suicide",
    "inconsiderate": {
      "failed suicide": "a",
      "failed attempt": "a",
      "suicide failure": "a"
    },
    "note": "Attempted suicide should not be depicted as a failure (source: https://www.speakingofsuicide.com/2013/04/13/language, https://www.afsp.org/news-events/for-the-media/reporting-on-suicide)",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "a note from the deceased": "a"
    },
    "id": "suicide-note",
    "inconsiderate": {
      "suicide note": "a"
    },
    "note": "Source: https://www.afsp.org/news-events/for-the-media/reporting-on-suicide",
    "type": "basic"
  },
  {
    "categories": [
      "a"
    ],
    "considerate": {
      "the app froze": "a",
      "the app stopped responding": "a",
      "the app stopped responding to events": "a",
      "the app became unresponsive": "a"
    },
    "id": "hang",
    "inconsiderate": {
      "hang": "a",
      "hanged": "a"
    },
    "note": "When describing the behavior of computer software, using the word “hanged” needlessly invokes the topic of death by self-harm or lynching.  Consider using the word “froze” or the phrase “stopped responding to events” or “became unresponsive” instead.",
    "type": "basic"
  }
]
